@@ -7,8 +7,8 @@ Each Graph data (for each structure):
 
 ``atom_fea``: np.ndarray, shape (N, atom_fea_len)
     center properties.
-``nbr_fea``: np.ndarray, shape (N, fill_size, atom_fea_len).
-    neighbor_indexes for each center_index.
+``nbr_fea``: np.ndarray, shape (N, fill_size, bond_fea_len).
+    neighbor properties for each center_index.
     `fill_size` default = 5.
 ``state_fea``: np.ndarray, shape (state_fea_len,)
     state feature.
@@ -24,6 +24,7 @@ from operator import itemgetter
 from typing import Union, Dict, List
 
 import numpy as np
+from deprecated.sphinx import deprecated
 from mgetool.tool import parallelize, batch_parallelize
 from pymatgen.analysis.local_env import NearNeighbors
 from pymatgen.core import Structure
@@ -53,6 +54,7 @@ def itemgetter_list(data_list: List, indices: List) -> tuple:
     return it(data_list)
 
 
+@deprecated(version='0.1.0')
 class _StructureGraph(BaseFeature):
     """
     Preferential use of _StructureGraphFixedRadius.
@@ -75,7 +77,7 @@ class _StructureGraph(BaseFeature):
         Parameters
         ----------
         nn_strategy : str
-            NearNeighbor strategy
+            NearNeighbor strategy.
             For bond_converter ="BaseNNGet": ["BrunnerNN_reciprocal", "BrunnerNN_real", "BrunnerNN_relative",
             "EconNN", "CrystalNN", "MinimumDistanceNNAll", "find_points_in_spheres","UserVoronoiNN"]
             For bond_converter ="BaseDesGet": ["ACSF","BehlerParrinello","EAD","EAMD","SOAP","SO3","SO4_Bispectrum","wACSF"]
@@ -263,12 +265,12 @@ class _StructureGraph(BaseFeature):
         iterables = zip(structures, state_attributes)
 
         if not self.batch_calculate:
-            rets = parallelize(self.n_jobs, self._wrapper, iterables, tq=True)
+            rets = parallelize(self.n_jobs, self._wrapper, iterables, tq=True,respective=True)
 
             ret, self.support_ = zip(*rets)
 
         else:
-            rets = batch_parallelize(self.n_jobs, self._wrapper, iterables, respective=False,
+            rets = batch_parallelize(self.n_jobs, self._wrapper, iterables, respective=True,
                                      tq=True, batch_size=self.batch_size)
 
             ret, self.support_ = zip(*rets)
